package com.sd.business.service.artwork.impl;

import cn.hutool.core.collection.CollUtil;
import com.sd.business.entity.artwork.po.ArtworkLibrary;
import com.sd.business.mapper.artwork.ArtworkLibraryMapper;
import com.sd.business.service.artwork.ArtworkLibraryService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.sd.business.entity.artwork.vo.ArtworkLibraryVo;
import com.sd.business.entity.artwork.dto.ArtworkLibrarySelectDto;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.sd.business.entity.artwork.dto.ArtworkLibraryDto;
import cn.hutool.core.bean.BeanUtil;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * <p>
 * 图稿库 服务实现类
 * </p>
 *
 * @author
 * @since 2023-08-02
 */
@Service
public class ArtworkLibraryServiceImpl extends ServiceImpl<ArtworkLibraryMapper, ArtworkLibrary> implements ArtworkLibraryService {

    @Override
    public List<ArtworkLibraryVo> getList(ArtworkLibrarySelectDto dto) {
        IWrapper<ArtworkLibrary> wrapper = getWrapper();
        wrapper.orderByDesc("al", ArtworkLibrary::getId);
        List<ArtworkLibraryVo> list = this.baseMapper.getList(wrapper);
        return list;
    }

    @Override
    public Page<ArtworkLibraryVo> getPage(ArtworkLibrarySelectDto dto) {
        IWrapper<ArtworkLibrary> wrapper = getWrapper();
        wrapper.orderByDesc("al", ArtworkLibrary::getId);
        Page<ArtworkLibraryVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        return page;
    }

    @Override
    public ArtworkLibraryVo detail(Long id) {
        ArtworkLibrary ArtworkLibrary = this.getById(id);
        ArtworkLibraryVo result = BeanUtil.toBean(ArtworkLibrary, ArtworkLibraryVo.class);
        return result;
    }

    /**
     * 新增图稿
     *
     * @param artworkLibraryDto
     */
    @Override
    public void add(ArtworkLibraryDto artworkLibraryDto) {

        String artworkName = artworkLibraryDto.getArtworkName();
        ArtworkLibrary artworkLibrary = baseMapper.getArtworkName(artworkName);
        if (artworkLibrary != null) {
            throw new SecurityException("该图稿已存在!");
        }
        ArtworkLibrary newArtworkLibrary = new ArtworkLibrary();
        BeanUtils.copyProperties(artworkLibraryDto, newArtworkLibrary);
        newArtworkLibrary.setId(artworkLibraryDto.getArtworkId());
        this.save(newArtworkLibrary);

    }

    /**
     * 修改图稿
     *
     * @param artworkLibraryDto
     */
    @Override
    public void edit(ArtworkLibraryDto artworkLibraryDto) {
        ArtworkLibrary artworkLibrary = baseMapper.selectById(artworkLibraryDto.getArtworkId());
        artworkLibrary.setArtworkName(artworkLibraryDto.getArtworkName());
        artworkLibrary.setArtworkUploadImgUrl(artworkLibraryDto.getArtworkUploadImgUrl());
        artworkLibrary.setArtworkUploadFileUrl(artworkLibraryDto.getArtworkUploadFileUrl());
        this.updateById(artworkLibrary);
    }

    /**
     * 删除图稿
     *
     * @param id
     */
    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

}
